Enum style::values::specified::length::Length
[−]
[src]
pub enum Length {
NoCalc(NoCalcLength),
Calc(Box<CalcLengthOrPercentage>),
}An extension to NoCalcLength to parse calc expressions.
This is commonly used for the <length> values.
Variants
NoCalc(NoCalcLength)The internal length type that cannot parse calc
Calc(Box<CalcLengthOrPercentage>)A calc expression.
Methods
impl Length[src]
pub fn zero() -> Length[src]
Returns a zero length.
pub fn parse_dimension(
context: &ParserContext,
value: CSSFloat,
unit: &str
) -> Result<Length, ()>[src]
context: &ParserContext,
value: CSSFloat,
unit: &str
) -> Result<Length, ()>
Parse a given absolute or relative dimension.
pub fn parse_non_negative<'i, 't>(
context: &ParserContext,
input: &mut Parser<'i, 't>
) -> Result<Length, ParseError<'i>>[src]
context: &ParserContext,
input: &mut Parser<'i, 't>
) -> Result<Length, ParseError<'i>>
Parse a non-negative length
pub fn parse_non_negative_quirky<'i, 't>(
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<Length, ParseError<'i>>[src]
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<Length, ParseError<'i>>
Parse a non-negative length, allowing quirks.
pub fn from_px(px_value: CSSFloat) -> Length[src]
Get an absolute length from a px value.
pub fn take(&mut self) -> Self[src]
Extract inner length without a clone, replacing it with a 0 Au
Use when you need to move out of a length array without cloning
impl Length[src]
pub fn parse_quirky<'i, 't>(
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<Self, ParseError<'i>>[src]
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<Self, ParseError<'i>>
Parses a length, with quirks.